@@ -16,6 +16,84 @@
 from tencentcloud.common.abstract_model import AbstractModel
 
 
+class AsyncRecognitionTaskInfo(AbstractModel):
+    """音频流异步识别任务信息
+
+    """
+
+    def __init__(self):
+        """
+        :param TaskId: 任务ID
+        :type TaskId: int
+        :param Url: 音频流Url
+        :type Url: str
+        """
+        self.TaskId = None
+        self.Url = None
+
+
+    def _deserialize(self, params):
+        self.TaskId = params.get("TaskId")
+        self.Url = params.get("Url")
+
+
+class AsyncRecognitionTasks(AbstractModel):
+    """音频流异步识别任务列表
+
+    """
+
+    def __init__(self):
+        """
+        :param Tasks: 任务列表
+注意：此字段可能返回 null，表示取不到有效值。
+        :type Tasks: list of AsyncRecognitionTaskInfo
+        """
+        self.Tasks = None
+
+
+    def _deserialize(self, params):
+        if params.get("Tasks") is not None:
+            self.Tasks = []
+            for item in params.get("Tasks"):
+                obj = AsyncRecognitionTaskInfo()
+                obj._deserialize(item)
+                self.Tasks.append(obj)
+
+
+class CloseAsyncRecognitionTaskRequest(AbstractModel):
+    """CloseAsyncRecognitionTask请求参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param TaskId: 语音流异步识别任务的唯一标识，在创建任务时会返回
+        :type TaskId: int
+        """
+        self.TaskId = None
+
+
+    def _deserialize(self, params):
+        self.TaskId = params.get("TaskId")
+
+
+class CloseAsyncRecognitionTaskResponse(AbstractModel):
+    """CloseAsyncRecognitionTask返回参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.RequestId = params.get("RequestId")
+
+
 class CreateAsrVocabRequest(AbstractModel):
     """CreateAsrVocab请求参数结构体
 
@@ -72,6 +150,86 @@ class CreateAsrVocabResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
+class CreateAsyncRecognitionTaskRequest(AbstractModel):
+    """CreateAsyncRecognitionTask请求参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param EngineType: 引擎模型类型。
+• 16k_zh：16k 中文普通话通用；
+• 16k_zh_video：16k 音视频领域；
+• 16k_en：16k 英语；
+• 16k_ca：16k 粤语；
+        :type EngineType: str
+        :param Url: 语音流地址，支持rtmp、hls、rtsp等流媒体协议，以及各类基于http协议的直播流
+        :type Url: str
+        :param CallbackUrl: 支持HTTP和HTTPS协议，用于接收识别结果，您需要自行搭建公网可调用的服务。回调格式&内容详见：[语音流异步识别回调说明](https://github.com/yunjianfei/qcloud-documents/blob/master/product/%E5%A4%A7%E6%95%B0%E6%8D%AE%E4%B8%8EAI/%E8%AF%AD%E9%9F%B3%E8%AF%86%E5%88%AB/%E8%AF%AD%E9%9F%B3%E8%AF%86%E5%88%AB%20API%202017/%E8%AF%AD%E9%9F%B3%E6%B5%81%E5%BC%82%E6%AD%A5%E8%AF%86%E5%88%AB%E5%9B%9E%E8%B0%83%E8%AF%B4%E6%98%8E.md)
+        :type CallbackUrl: str
+        :param SignToken: 用于生成回调通知中的签名
+        :type SignToken: str
+        :param FilterDirty: 是否过滤脏词（目前支持中文普通话引擎）。0：不过滤脏词；1：过滤脏词；2：将脏词替换为 * 。默认值为 0
+        :type FilterDirty: int
+        :param FilterModal: 是否过语气词（目前支持中文普通话引擎）。0：不过滤语气词；1：部分过滤；2：严格过滤 。默认值为 0
+        :type FilterModal: int
+        :param FilterPunc: 是否过滤标点符号（目前支持中文普通话引擎）。 0：不过滤，1：过滤句末标点，2：过滤所有标点。默认为0
+        :type FilterPunc: int
+        :param ConvertNumMode: 是否进行阿拉伯数字智能转换。0：不转换，直接输出中文数字，1：根据场景智能转换为阿拉伯数字。默认值为1
+        :type ConvertNumMode: int
+        :param WordInfo: 是否显示词级别时间戳。0：不显示；1：显示，不包含标点时间戳，2：显示，包含标点时间戳。默认为0
+        :type WordInfo: int
+        :param HotwordId: 热词id。用于调用对应的热词表，如果在调用语音识别服务时，不进行单独的热词id设置，自动生效默认热词；如果进行了单独的热词id设置，那么将生效单独设置的热词id。
+        :type HotwordId: str
+        """
+        self.EngineType = None
+        self.Url = None
+        self.CallbackUrl = None
+        self.SignToken = None
+        self.FilterDirty = None
+        self.FilterModal = None
+        self.FilterPunc = None
+        self.ConvertNumMode = None
+        self.WordInfo = None
+        self.HotwordId = None
+
+
+    def _deserialize(self, params):
+        self.EngineType = params.get("EngineType")
+        self.Url = params.get("Url")
+        self.CallbackUrl = params.get("CallbackUrl")
+        self.SignToken = params.get("SignToken")
+        self.FilterDirty = params.get("FilterDirty")
+        self.FilterModal = params.get("FilterModal")
+        self.FilterPunc = params.get("FilterPunc")
+        self.ConvertNumMode = params.get("ConvertNumMode")
+        self.WordInfo = params.get("WordInfo")
+        self.HotwordId = params.get("HotwordId")
+
+
+class CreateAsyncRecognitionTaskResponse(AbstractModel):
+    """CreateAsyncRecognitionTask返回参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param Data: 请求返回结果，包含本次的任务ID(TaskId)
+        :type Data: :class:`tencentcloud.asr.v20190614.models.Task`
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.Data = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        if params.get("Data") is not None:
+            self.Data = Task()
+            self.Data._deserialize(params.get("Data"))
+        self.RequestId = params.get("RequestId")
+
+
 class CreateCustomizationRequest(AbstractModel):
     """CreateCustomization请求参数结构体
 
@@ -141,7 +299,7 @@ class CreateRecTaskRequest(AbstractModel):
 • 16k_ja：16k 日语；
 • 16k_wuu-SH：16k 上海话方言；
         :type EngineModelType: str
-        :param ChannelNum: 语音声道数。1：单声道；2：双声道（仅支持 8k_zh 引擎模型）。
+        :param ChannelNum: 识别声道数。1：单声道；2：双声道（仅支持 8k_zh 引擎模）。注意：录音识别会自动将音频转码为填写的识别声道数
         :type ChannelNum: int
         :param ResTextFormat: 识别结果返回形式。0： 识别结果文本(含分段时间戳)； 1：词级别粒度的[详细识别结果](https://cloud.tencent.com/document/api/1093/37824#SentenceDetail)(不含标点，含语速值)；2：词级别粒度的详细识别结果（包含标点、语速值）
         :type ResTextFormat: int
@@ -152,7 +310,7 @@ class CreateRecTaskRequest(AbstractModel):
         :param SpeakerNumber: 说话人分离人数（需配合开启说话人分离使用），取值范围：0-10，0代表自动分离（目前仅支持≤6个人），1-10代表指定说话人数分离。
 注：话者分离目前是beta版本，请根据您的需要谨慎使用
         :type SpeakerNumber: int
-        :param CallbackUrl: 回调 URL，用户自行搭建的用于接收识别结果的服务器地址， 长度小于2048字节。如果用户使用回调方式获取识别结果，需提交该参数；如果用户使用轮询方式获取识别结果，则无需提交该参数。
+        :param CallbackUrl: 回调 URL，用户自行搭建的用于接收识别结果的服务URL。如果用户使用轮询方式获取识别结果，则无需提交该参数。回调格式&内容详见：[录音识别回调说明](https://github.com/yunjianfei/qcloud-documents/blob/master/product/%E5%A4%A7%E6%95%B0%E6%8D%AE%E4%B8%8EAI/%E8%AF%AD%E9%9F%B3%E8%AF%86%E5%88%AB/%E8%AF%AD%E9%9F%B3%E8%AF%86%E5%88%AB%20API%202017/%E5%BD%95%E9%9F%B3%E8%AF%86%E5%88%AB%E5%9B%9E%E8%B0%83%E8%AF%B4%E6%98%8E.md)
         :type CallbackUrl: str
         :param Url: 语音的URL地址，需要公网可下载。长度小于2048字节，当 SourceType 值为 0 时须填写该字段，为 1 时不需要填写。注意：请确保录音文件时长在5个小时之内，否则可能识别失败。请保证文件的下载速度，否则可能下载失败。
         :type Url: str
@@ -301,6 +459,36 @@ class DeleteCustomizationResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
+class DescribeAsyncRecognitionTasksRequest(AbstractModel):
+    """DescribeAsyncRecognitionTasks请求参数结构体
+
+    """
+
+
+class DescribeAsyncRecognitionTasksResponse(AbstractModel):
+    """DescribeAsyncRecognitionTasks返回参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param Data: 任务列表
+注意：此字段可能返回 null，表示取不到有效值。
+        :type Data: :class:`tencentcloud.asr.v20190614.models.AsyncRecognitionTasks`
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.Data = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        if params.get("Data") is not None:
+            self.Data = AsyncRecognitionTasks()
+            self.Data._deserialize(params.get("Data"))
+        self.RequestId = params.get("RequestId")
+
+
 class DescribeTaskStatusRequest(AbstractModel):
     """DescribeTaskStatus请求参数结构体
 
@@ -1032,7 +1220,7 @@ class Task(AbstractModel):
 
     def __init__(self):
         """
-        :param TaskId: 任务ID，可通过此ID在轮询接口获取识别状态与结果
+        :param TaskId: 任务ID，可通过此ID在轮询接口获取识别状态与结果。注意：TaskId数据类型为uint64
         :type TaskId: int
         """
         self.TaskId = None
